@@ -1,5 +1,5 @@
 /*
-  Copyright 2013-2018 Laurent Montel <montel@kde.org>
+  Copyright 2013-2019 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -21,7 +21,7 @@
 #define ADDEMAILDISPLAYJOB_H
 
 #include "kdepimakonadi_export.h"
-
+#include <AkonadiCore/Item>
 #include <kjob.h>
 
 namespace Akonadi {
@@ -29,6 +29,10 @@ class Item;
 }
 
 namespace KPIM {
+/**
+ * @brief The AddEmailDiplayJob class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KDEPIMAKONADI_EXPORT AddEmailDiplayJob : public KJob
 {
     Q_OBJECT
@@ -40,9 +44,13 @@ public:
     void setShowAsHTML(bool html);
     void setRemoteContent(bool b);
     void setContact(const Akonadi::Item &contact);
+    void setMessageId(Akonadi::Item::Id id);
 
     void start() override;
 
+Q_SIGNALS:
+    void contactUpdated(const Akonadi::Item &contact, Akonadi::Item::Id id);
+
 private:
     //@cond PRIVATE
     class Private;
